<a id="utils.timestamp.time"></a>

## time

<a id="utils.timestamp.time_since"></a>

#### time\_since

```python
def time_since(timestamp)
```

<a id="utils.timestamp.TimeStamp"></a>

## TimeStamp Objects

```python
class TimeStamp()
```

<a id="utils.timestamp.TimeStamp.__init__"></a>

#### \_\_init\_\_

```python
def __init__()
```

<a id="utils.timestamp.TimeStamp.time_since"></a>

#### time\_since

```python
def time_since(timestamp=None)
```

<a id="utils.timestamp.TimeStamp.update"></a>

#### update

```python
def update()
```

<a id="utils.timestamp.TimeStamp.__repr__"></a>

#### \_\_repr\_\_

```python
def __repr__()
```

